#
# spec file for package sccache
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%global rustflags -Clink-arg=-Wl,-z,relro,-z,now -C debuginfo=2
%define configdir %{_sysconfdir}/%{name}

Name:           sccache
Version:        0.2.13~git474.6628e1f
Release:        lp152.2.1
Summary:        A compiler caching tool for Rust, C and C++ with optional cloud storage
License:        Apache-2.0
Group:          Development/Languages/Rust
Url:            https://github.com/mozilla/%{name}
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
Source10:       sccache-dist-builder.service
Source11:       sccache-dist-scheduler.service
Source12:       builder.conf
Source13:       scheduler.conf
Source14:       client.example
BuildRequires:  rust-packaging
BuildRequires:  pkgconfig(openssl)
Requires:       bubblewrap
ExcludeArch:    s390 s390x ppc ppc64 ppc64le %ix86

%description
Sccache is a ccache-like tool. It is used as a compiler wrapper and
avoids compilation when possible, storing a cache in a remote storage
using the Amazon Simple Cloud Storage Service (S3) API, Redis or
the Google Cloud Storage (GCS) API.

%prep
%setup -q
%setup -qa1
mkdir .cargo
cp %{SOURCE2} .cargo/config
# Remove exec bits to prevent an issue in fedora shebang checking
find vendor -type f -name \*.rs -exec chmod -x '{}' \;

%build
export RUSTFLAGS="%{rustflags}"
cargo build --offline --release --features=all,dist-server,dist-client

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -D -d -m 0755 %{buildroot}%{_unitdir}
install -D -d -m 0755 %{buildroot}%{configdir}

install -m 0755 %{_builddir}/%{name}-%{version}/target/release/sccache %{buildroot}%{_bindir}/sccache
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/sccache-dist %{buildroot}%{_bindir}/sccache-dist

install -m 0644 %{SOURCE10} %{buildroot}%{_unitdir}/sccache-dist-builder.service
install -m 0644 %{SOURCE11} %{buildroot}%{_unitdir}/sccache-dist-scheduler.service
install -m 0644 %{SOURCE12} %{buildroot}%{configdir}/builder.conf
install -m 0644 %{SOURCE13} %{buildroot}%{configdir}/scheduler.conf
install -m 0644 %{SOURCE14} %{buildroot}%{configdir}/client.example

%pre
%service_add_pre sccache-dist-builder.service
%service_add_pre sccache-dist-scheduler.service

%post
%service_add_post sccache-dist-builder.service
%service_add_post sccache-dist-scheduler.service

%preun
%service_del_preun sccache-dist-builder.service
%service_del_preun sccache-dist-scheduler.service

%postun
%service_del_postun sccache-dist-builder.service
%service_del_postun sccache-dist-scheduler.service

%files
%license LICENSE
%doc README.md
%{_bindir}/sccache
%{_bindir}/sccache-dist

%{_unitdir}/sccache-dist-builder.service
%{_unitdir}/sccache-dist-scheduler.service

%dir %{configdir}
%config(noreplace) %{configdir}/scheduler.conf
%config(noreplace) %{configdir}/builder.conf
%config(noreplace) %{configdir}/client.example

%changelog
* Fri Nov 20 2020 William Brown <william.brown@suse.com>
- Fix service file commit definition
- Correct spec file example install
* Thu Nov 19 2020 wbrown@suse.de
- Update to version 0.2.13~git474.6628e1f:
  * New entry in ServerStartup enum to indicate AddrInUse Error (#840)
  * Revert "Bump to tiny-http 0.7.0 (#830)" because it caused a regression, #846.
  * Include -fsanitizer-blacklist in common_args
  * Consume sanitizer blacklist as extra hash in msvc (#842)
  * In case we fail to read the compressed content from the cache, treat the failure as a forced
    recache. This prevents us from failing build jobs unconditionally if cache entries are corrupt
    (or in case of other sporadic failures), in which case we should continue on with
    force-recompiling and recaching. (#836)
  * Bump to tiny-http 0.7.0 (#830)
  * Modify logging to use SCCACHE_LOG. (#822)
  * Implement `g++` and `clang++` behavior when used on a `.c` input file. Fixes #803 (#818)
  * clang: Allow chrome plugin arguments (#817)
  * Add known caveats section to readme (#815)
* Wed Nov 18 2020 William Brown <william.brown@suse.com>
- Configure features to generate sccache-dist for distributed builds.
- Add systemd unit files for builder and scheduler and example configs.
* Wed Nov 18 2020 William Brown <william.brown@suse.com>
- Add --features=all to allow all cache backends to be used.
* Tue Nov 17 2020 William Brown <william.brown@suse.com>
- Add support for obs cargo vendor to make packaging easier.
  * osc service ra - now can update the source files.
- Improvements to spec file.
- Fix invalid license string.
* Fri May 22 2020 Sumit Jamgade <sjamgade@suse.com>
- Initial Package
